@@ -2,6 +2,7 @@
 Helper utilities for blight.
 """
 
+import argparse
 import contextlib
 import fcntl
 import os
@@ -138,7 +139,7 @@ def load_actions():
     Loads any blight actions requested via the environment.
 
     Each action is loaded from the `BLIGHT_ACTIONS` environment variable,
-    separated by colons.
+    separated by colons. Duplicate actions are removed.
 
     For example, the following loads the `Record` and `Benchmark` actions:
 
@@ -168,11 +169,11 @@ def load_actions():
     import blight.actions
 
     action_names = os.getenv("BLIGHT_ACTIONS")
-    if action_names is None:
+    if not action_names:
         return []
 
     actions = []
-    for action_name in action_names.split(":"):
+    for action_name in set(action_names.split(":")):
         action_class = getattr(blight.actions, action_name, None)
         if action_class is None:
             raise BlightError(f"Unknown action: {action_name}")
@@ -186,3 +187,22 @@ def load_actions():
 
         actions.append(action_class(action_config))
     return actions
+
+
+class ArgumentParser(argparse.ArgumentParser):
+    """
+    A wrapper around `argparse.ArgumentParser` with non-exiting error behavior.
+
+    Parsing errors raise `ValueError` instead.
+    """
+
+    def error(self, message) -> NoReturn:
+        raise ValueError(message)
+
+    def default_namespace(self) -> argparse.Namespace:
+        """
+        Returns a default `argparse.Namespace`, suitable for contexts where
+        argument parsing fails completely.
+        """
+        defaults = {action.dest: self.get_default(action.dest) for action in self._actions}
+        return argparse.Namespace(**defaults)
